"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
const fs = require("fs-extra");
const utils_1 = require("../helpers/utils");
const pathHelper_1 = require("../helpers/pathHelper");
const config_1 = require("../config/config");
const envHelper_1 = require("../helpers/envHelper");
exports.default = {
    command: 'extras [sub_command] [options]',
    describe: 'Additional commands (undocumented features)',
    handler: commandHandler,
    builder: commandBuilder
};
function commandBuilder(yargs) {
    return yargs
        .example('napp extras archive', 'Archive app sources');
}
function commandHandler(argv) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!argv.sub_command)
            return;
        envHelper_1.default.checkFolderStructure();
        switch (argv.sub_command) {
            case 'archive':
                yield utils_1.default.logOperation('Archive app sources', archive);
                break;
            default:
                break;
        }
    });
}
function archive() {
    return __awaiter(this, void 0, void 0, function* () {
        let archiveDir = pathHelper_1.default.projectRelative(config_1.default.paths.archive.root);
        let archiveFileName = `${envHelper_1.default.getAppName()}_src.zip`;
        let archivePath = pathHelper_1.default.projectRelative(archiveFileName);
        utils_1.default.ensureEmptyDir(archiveDir);
        let exclude = [
            pathHelper_1.default.clientRelative(config_1.default.paths.client.build),
            pathHelper_1.default.projectRelative(config_1.default.paths.build.root),
            pathHelper_1.default.projectRelative(config_1.default.paths.deploy.root),
            pathHelper_1.default.projectRelative(config_1.default.paths.archive.root),
            pathHelper_1.default.serverRelative('./node_modules'),
            pathHelper_1.default.serverRelative(config_1.default.paths.server.build),
            pathHelper_1.default.serverRelative(config_1.default.paths.server.local),
            pathHelper_1.default.clientRelative('./node_modules'),
            archivePath
        ];
        fs.copySync(pathHelper_1.default.projectRelative('./'), archiveDir, {
            filter: (path) => {
                for (let excludePath of exclude) {
                    if (_.startsWith(path, excludePath)) {
                        return false;
                    }
                }
                return true;
            }
        });
        yield utils_1.default.archiveFolder(archiveDir, archivePath);
        utils_1.default.removeDir(archiveDir);
    });
}
//# sourceMappingURL=extras.js.map